@@ -10,8 +10,8 @@ test_that("correct api vals given: 1 reporter, 1 partner, imports, monthly", {
                     partners = "Germany",
                     trade_direction = "imports",
                     freq = "monthly",
-                    start_date = "2011-01-01",
-                    end_date = "2011-05-01")
+                    start_date = "2011-01",
+                    end_date = "2011-05")
 
   # Data type.
   expect_is(vals, "data.frame")
@@ -79,6 +79,18 @@ test_that(msg, {
 })
 
 
+test_that("correct api vals given: type == 'services'", {
+  vals <- ct_search(reporters = "USA",
+                    partners = "World",
+                    freq = "annual",
+                    start_date = "2015-01-01",
+                    end_date = "2015-12-31",
+                    commod_codes = "TOTAL",
+                    type = "services")
+  expect_true(nrow(vals) > 0)
+})
+
+
 test_that("throw error with invalid input to arg 'reporters'", {
   expect_error(ct_search(reporters = "invalid_reporter",
                          partners = "Germany",
@@ -120,16 +132,6 @@ test_that("throw error with invalid input to arg 'freq'", {
 })
 
 
-test_that("throw error with invalid input to arg 'start_date' & 'end_date'", {
-  expect_error(ct_search(reporters = "Canada",
-                         partners = "Germany",
-                         trade_direction = "imports",
-                         freq = "monthly",
-                         start_date = "1/1/2011",
-                         end_date = "5/1/2011"))
-})
-
-
 test_that("throw error with invalid input to arg 'commod_codes'", {
   skip_on_cran()
 
@@ -183,3 +185,39 @@ test_that("throw error when hourly query limit is at zero", {
   # Set the rate limit value back to what it was previously.
   assign("queries_this_hour", cache_vals$queries_this_hour, envir = ct_env)
 })
+
+
+test_that("throw error with invalid input to arg 'start_date' & 'end_date'", {
+  expect_error(ct_search(reporters = "Canada",
+               partners = "Germany",
+               trade_direction = "imports",
+               freq = "monthly",
+               start_date = "1/1/2011",
+               end_date = "5/1/2011"),
+  regexp = "arg 'start_date' must be a date with one of these formats:")
+})
+
+
+test_that("different date inputs produce correct date ranges", {
+  # Tests with "freq" is "annual".
+  expect_equal(get_date_range("2016", "2016", "A"), "2016")
+  expect_equal(get_date_range("2016-01-01", 2016, "A"), "2016")
+  expect_equal(get_date_range("2013", "2016", "A"),
+               "2013%2C2014%2C2015%2C2016")
+  expect_equal(get_date_range(2010, 2012, "A"), "2010%2C2011%2C2012")
+  expect_error(
+    get_date_range("2008", "2016", "A"),
+    regexp = "cannot search more than five consecutive years/months"
+  )
+
+  # Tests with "freq" as "monthly".
+  expect_equal(get_date_range("2016-01-01", "2016-05", "M"),
+               "201601%2C201602%2C201603%2C201604%2C201605")
+  expect_equal(get_date_range(2016, 2016, "M"), "2016")
+  expect_error(get_date_range("2013", "2016", "M"),
+               regexp = "Cannot get more than a single year's worth")
+  expect_error(
+    get_date_range(2015, "2015-03", "M"),
+    rexexp = "'start_date' and 'end_date' must have the same format"
+  )
+})
